@@ -495,9 +495,9 @@ class Purchase(
 
     @fields.depends('lines', 'currency', methods=['get_tax_amount'])
     def on_change_lines(self):
-        self.untaxed_amount = Decimal('0.0')
-        self.tax_amount = Decimal('0.0')
-        self.total_amount = Decimal('0.0')
+        self.untaxed_amount = Decimal(0)
+        self.tax_amount = Decimal(0)
+        self.total_amount = Decimal(0)
         if self.lines:
             for line in self.lines:
                 self.untaxed_amount += getattr(line, 'amount', None) or 0
@@ -733,6 +733,9 @@ class Purchase(
         default.setdefault('purchase_date', None)
         default.setdefault('quoted_by')
         default.setdefault('confirmed_by')
+        default.setdefault('untaxed_amount_cache')
+        default.setdefault('tax_amount_cache')
+        default.setdefault('total_amount_cache')
         return super(Purchase, cls).copy(purchases, default=default)
 
     def check_for_quotation(self):
@@ -910,7 +913,11 @@ class Purchase(
     @Workflow.transition('draft')
     @reset_employee('quoted_by', 'confirmed_by')
     def draft(cls, purchases):
-        pass
+        cls.write(purchases, {
+                'tax_amount_cache': None,
+                'untaxed_amount_cache': None,
+                'total_amount_cache': None,
+                })
 
     @classmethod
     @ModelView.button
@@ -1434,7 +1441,7 @@ class Line(sequence_ordered(), ModelSQL, ModelView):
         if self.type == 'line':
             return self.on_change_with_amount()
         elif self.type == 'subtotal':
-            amount = Decimal('0.0')
+            amount = Decimal(0)
             for line2 in self.purchase.lines:
                 if line2.type == 'line':
                     amount += line2.purchase.currency.round(
@@ -1442,7 +1449,7 @@ class Line(sequence_ordered(), ModelSQL, ModelView):
                 elif line2.type == 'subtotal':
                     if self == line2:
                         break
-                    amount = Decimal('0.0')
+                    amount = Decimal(0)
             return amount
         return Decimal('0.0')
 
